Structs
- Alpn
Error - An error returned from an ALPN selection callback.
- Async
Private KeyMethod Error - A fatal error to be returned from async private key methods.
- Async
Select Cert Error - A fatal error to be returned from async select certificate callbacks.
- Certificate
Compression Algorithm - Cipher
Bits - Information about the state of a cipher.
- Client
Hello - Compliance
Policy - A compliance policy.
- Connect
Configuration - A type which allows for configuration of a client-side TLS session before connection.
- Error
- A general SSL error, based on
SSL_ERROR_*error codes. - Error
Code SSL_ERROR_*error code returned from SSL functions.- Extension
Type - Extension types, to be used with
ClientHello::get_extension. - GetSession
Pending Error - Error returned by the callback to get a session when operation could not complete and should be retried later.
- Handshake
Error - The error type returned after a failed handshake.
- Handshake
Future - Future for an ongoing TLS handshake.
- MidHandshake
SslStream - An SSL stream midway through the handshake process.
- Name
Type - An identifier of a session name type.
- Private
KeyMethod Error - An error returned from a private key method.
- Select
Cert Error - An error returned from a certificate selection callback.
- Shutdown
State - The shutdown state of a session.
- SniError
- An error returned from the SNI callback.
- Ssl
- The state of an SSL/TLS session.
- Ssl3
Alert Level - SslAcceptor
- A type which wraps server-side streams in a TLS session.
- SslAcceptor
Builder - A builder for
SslAcceptors. - SslAlert
- An SSL/TLS alert.
- SslCipher
- Information about a cipher.
- SslCipher
Ref - Reference to an
SslCipher. - SslConnector
- A type which wraps client-side streams in a TLS session.
- SslConnector
Builder - A builder for
SslConnectors. - SslContext
- A context object for TLS streams.
- SslContext
Builder - A builder for
SslContexts. - SslContext
Ref - A borrowed reference to a
SslContext. - SslCurve
- A TLS Curve.
- SslCurve
Nid - Numeric identifier of a TLS curve.
- SslEch
Keys - SslEch
Keys Ref - A borrowed reference to a
SslEchKeys. - SslFiletype
- An identifier of the format of a certificate or key file.
- SslInfo
Callback Alert - SslInfo
Callback Mode - Options controlling the behavior of the info callback.
- SslMethod
- A type specifying the kind of protocol an
SslContextwill speak. - SslMode
- Options controlling the behavior of an
SslContext. - SslOptions
- Options controlling the behavior of an
SslContext. - SslRef
- A borrowed reference to a
Ssl. - SslSession
- An encoded SSL session.
- SslSession
Cache Mode - Options controlling the behavior of session caching.
- SslSession
Ref - A borrowed reference to a
SslSession. - SslSignature
Algorithm - A signature verification algorithm.
- SslStream
- A wrapper around an underlying raw stream which implements the SSL protocol.
- SslStream
Builder - A partially constructed
SslStream, useful for unusual handshakes. - SslVerify
Mode - Options controlling the behavior of certificate verification.
- SslVersion
- An SSL/TLS protocol version.
- Status
Type - An identifier of a certificate status type.
Enums
- Shutdown
Result - The result of a shutdown request.
- SslInfo
Callback Value - The
valueargument to an info callback. The most-significant byte is the alert level, while the least significant byte is the alert itself. - SslVerify
Error
Traits
- Async
Private KeyMethod - Describes async private key hooks. This is used to off-load signing operations to a custom, potentially asynchronous, backend. Metadata about the key such as the type and size are parsed out of the certificate.
- Certificate
Compressor - Describes certificate compression algorithm. Implementation MUST implement transformation at least in one direction.
- Private
KeyMethod - Describes private key hooks. This is used to off-load signing operations to a custom, potentially asynchronous, backend. Metadata about the key such as the type and size are parsed out of the certificate.
- SslContext
Builder Ext - Extensions to
SslContextBuilder.
Functions
- accept
- Asynchronously performs a server-side TLS handshake over the provided stream.
- connect
- Asynchronously performs a client-side TLS handshake over the provided stream.
- select_
next_ proto - A standard implementation of protocol selection for Application Layer Protocol Negotiation (ALPN).
Type Aliases
- BoxCustom
Verify Finish - The type of callbacks returned by
BoxCustomVerifyFuturemethods. - BoxCustom
Verify Future - The type of futures to pass to
SslContextBuilder::set_async_custom_verify_callback. - BoxGet
Session Finish - The type of callbacks returned by
BoxSelectCertFuturemethods. - BoxGet
Session Future - The type of futures to pass to
SslContextBuilder::set_async_get_session_callback. - BoxPrivate
KeyMethod Finish - The type of callbacks returned by
BoxPrivateKeyMethodFuture. - BoxPrivate
KeyMethod Future - The type of futures returned by
AsyncPrivateKeyMethodmethods. - BoxSelect
Cert Finish - The type of callbacks returned by
BoxSelectCertFuturemethods. - BoxSelect
Cert Future - The type of futures to pass to
SslContextBuilder::set_async_select_certificate_callback. - ExData
Future - Convenience alias for futures stored in
Sslex data bySslContextBuildermethods.